Example using under-sampling class methods — Version 0.11.0.dev0

# Example using under-sampling class methods

Under-sampling refers to the process of reducing the number of samples in the majority classes. The implemented methods can be categorized into 2 groups: (i) fixed under-sampling and (ii) cleaning under-sampling.

Illustration of the definition of a Tomek link

Illustration of the definition of a Tomek link

Sample selection in NearMiss

Sample selection in NearMiss

Compare under-sampling samplers

Compare under-sampling samplers

previous

Usage of pipeline embedding samplers

next

Illustration of the definition of a Tomek link